@@ -1,7 +1,7 @@
 #
 # This file is part of the PyMeasure package.
 #
-# Copyright (c) 2013-2017 PyMeasure Developers
+# Copyright (c) 2013-2019 PyMeasure Developers
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -22,11 +22,16 @@
 # THE SOFTWARE.
 #
 
-from .adapter import Adapter
+import logging
 
 import serial
 import numpy as np
 
+from .adapter import Adapter
+
+log = logging.getLogger(__name__)
+log.addHandler(logging.NullHandler())
+
 
 class SerialAdapter(Adapter):
     """ Adapter class for using the Python Serial package to allow
@@ -37,7 +42,10 @@ class SerialAdapter(Adapter):
     """
 
     def __init__(self, port, **kwargs):
-        self.connection = serial.Serial(port, **kwargs)
+        if isinstance(port, serial.Serial):
+            self.connection = port
+        else:
+            self.connection = serial.Serial(port, **kwargs)
 
     def __del__(self):
         """ Ensures the connection is closed upon deletion
@@ -49,7 +57,7 @@ class SerialAdapter(Adapter):
 
         :param command: SCPI command string to be sent to the instrument
         """
-        self.connection.write(command.encode()) # encode added for Python 3
+        self.connection.write(command.encode())  # encode added for Python 3
 
     def read(self):
         """ Reads until the buffer is empty and returns the resulting
