@@ -1,7 +1,7 @@
 #
 # This file is part of the PyMeasure package.
 #
-# Copyright (c) 2013-2017 PyMeasure Developers
+# Copyright (c) 2013-2019 PyMeasure Developers
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,11 +23,13 @@
 #
 
 import logging
+
+import numpy as np
+
 log = logging.getLogger(__name__)
 log.addHandler(logging.NullHandler())
 
-import numpy as np
-from datetime.datetime import now
+log.warning('not implemented yet')
 
 
 class ProgressBar(object):
@@ -38,7 +40,7 @@ class ProgressBar(object):
 
     def __init__(self):
         self.data = np.empty()
-        self.progress_precents = []
+        self.progress_percentage = []
         self.progress_times = []
 
     def advance(self, progress):
@@ -58,4 +60,4 @@ def display(log, port, level=logging.INFO):
     """ Displays the log to the console with a progress bar
     that always remains at the bottom of the screen and refreshes itself
     """
-    pass
\ No newline at end of file
+    pass
