@@ -1,7 +1,7 @@
 #
 # This file is part of the PyMeasure package.
 #
-# Copyright (c) 2013-2017 PyMeasure Developers
+# Copyright (c) 2013-2019 PyMeasure Developers
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,17 +21,19 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 #
+
 import configparser
 import logging
-from .results import unique_filename
-import numpy as np
-import signal
-from pymeasure.log import setup_logging
 import os
 
+log = logging.getLogger(__name__)
+log.addHandler(logging.NullHandler())
+
+
 def set_file(filename):
     os.environ['CONFIG'] = filename
 
+
 def get_config(filename='default_config.ini'):
     if 'CONFIG' in os.environ.keys():
         filename = os.environ['CONFIG']
@@ -39,8 +41,10 @@ def get_config(filename='default_config.ini'):
     config.read(filename)
     return config
 
+
+# noinspection PyProtectedMember
 def set_mpl_rcparams(config):
     if 'matplotlib.rcParams' in config._sections.keys():
         import matplotlib
         for key in config._sections['matplotlib.rcParams']:
-            matplotlib.rcParams[key] = eval(config._sections['matplotlib.rcParams'][key])
\ No newline at end of file
+            matplotlib.rcParams[key] = eval(config._sections['matplotlib.rcParams'][key])
