@@ -1,7 +1,7 @@
 #
 # This file is part of the PyMeasure package.
 #
-# Copyright (c) 2013-2016 PyMeasure Developers
+# Copyright (c) 2013-2019 PyMeasure Developers
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -58,9 +58,9 @@ class Keithley2000(Instrument, KeithleyBuffer):
     mode = Instrument.control(
         ":CONF?", ":CONF:%s",
         """ A string property that controls the configuration mode for measurements,
-        which can take the values: :code:'current' (DC), :code:'current ac', 
-        :code:'voltage' (DC),  :code:'voltage ac', :code:'resistance' (2-wire), 
-        :code:'resistance 4W' (4-wire), :code:'period', :code:'frequency', 
+        which can take the values: :code:'current' (DC), :code:'current ac',
+        :code:'voltage' (DC),  :code:'voltage ac', :code:'resistance' (2-wire),
+        :code:'resistance 4W' (4-wire), :code:'period', :code:'frequency',
         :code:'temperature', :code:'diode', and :code:'frequency'. """,
         validator=strict_discrete_set,
         values=MODES,
@@ -68,22 +68,32 @@ class Keithley2000(Instrument, KeithleyBuffer):
         get_process=lambda v: v.replace('"', '')
     )
 
+    beep_state = Instrument.control(
+        ":SYST:BEEP:STAT?",
+        ":SYST:BEEP:STAT %g",
+        """ A string property that enables or disables the system status beeper,
+        which can take the values: :code:'enabled' and :code:'disabled'. """,
+        validator=strict_discrete_set,
+        values={'enabled':1, 'disabled':0},
+        map_values=True
+    )
+
     ###############
     # Current (A) #
     ###############
 
     current = Instrument.measurement(":READ?",
         """ Reads a DC or AC current measurement in Amps, based on the
-        active :attr:`~.mode`. """
+        active :attr:`~.Keithley2000.mode`. """
     )
     current_range = Instrument.control(
         ":SENS:CURR:RANG?", ":SENS:CURR:RANG:AUTO 0;:SENS:CURR:RANG %g",
         """ A floating point property that controls the DC current range in
-        Amps, which can take values from 0 to 3.1 A. 
+        Amps, which can take values from 0 to 3.1 A.
         Auto-range is disabled when this property is set. """,
         validator=truncated_range,
         values=[0, 3.1]
-    )  
+    )
     current_reference = Instrument.control(
         ":SENS:CURR:REF?", ":SENS:CURR:REF %g",
         """ A floating point property that controls the DC current reference
@@ -94,7 +104,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
     current_nplc = Instrument.control(
         ":SENS:CURR:NPLC?", ":SENS:CURR:NPLC %g",
         """ A floating point property that controls the number of power line cycles
-        (NPLC) for the DC current measurements, which sets the integration period 
+        (NPLC) for the DC current measurements, which sets the integration period
         and measurement speed. Takes values from 0.01 to 10, where 0.1, 1, and 10 are
         Fast, Medium, and Slow respectively. """
     )
@@ -109,7 +119,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
     current_ac_range = Instrument.control(
         ":SENS:CURR:AC:RANG?", ":SENS:CURR:AC:RANG:AUTO 0;:SENS:CURR:AC:RANG %g",
         """ A floating point property that controls the AC current range in
-        Amps, which can take values from 0 to 3.1 A. 
+        Amps, which can take values from 0 to 3.1 A.
         Auto-range is disabled when this property is set. """,
         validator=truncated_range,
         values=[0, 3.1]
@@ -124,7 +134,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
     current_ac_nplc = Instrument.control(
         ":SENS:CURR:AC:NPLC?", ":SENS:CURR:AC:NPLC %g",
         """ A floating point property that controls the number of power line cycles
-        (NPLC) for the AC current measurements, which sets the integration period 
+        (NPLC) for the AC current measurements, which sets the integration period
         and measurement speed. Takes values from 0.01 to 10, where 0.1, 1, and 10 are
         Fast, Medium, and Slow respectively. """
     )
@@ -150,7 +160,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
 
     voltage = Instrument.measurement(":READ?",
         """ Reads a DC or AC voltage measurement in Volts, based on the
-        active :attr:`~.mode`. """
+        active :attr:`~.Keithley2000.mode`. """
     )
     voltage_range = Instrument.control(
         ":SENS:VOLT:RANG?", ":SENS:VOLT:RANG:AUTO 0;:SENS:VOLT:RANG %g",
@@ -170,7 +180,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
     voltage_nplc = Instrument.control(
         ":SENS:CURRVOLT:NPLC?", ":SENS:VOLT:NPLC %g",
         """ A floating point property that controls the number of power line cycles
-        (NPLC) for the DC voltage measurements, which sets the integration period 
+        (NPLC) for the DC voltage measurements, which sets the integration period
         and measurement speed. Takes values from 0.01 to 10, where 0.1, 1, and 10 are
         Fast, Medium, and Slow respectively. """
     )
@@ -185,7 +195,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
     voltage_ac_range = Instrument.control(
         ":SENS:VOLT:AC:RANG?", ":SENS:VOLT:RANG:AUTO 0;:SENS:VOLT:AC:RANG %g",
         """ A floating point property that controls the AC voltage range in
-        Volts, which can take values from 0 to 757.5 V. 
+        Volts, which can take values from 0 to 757.5 V.
         Auto-range is disabled when this property is set. """,
         validator=truncated_range,
         values=[0, 757.5]
@@ -200,7 +210,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
     voltage_ac_nplc = Instrument.control(
         ":SENS:VOLT:AC:NPLC?", ":SENS:VOLT:AC:NPLC %g",
         """ A floating point property that controls the number of power line cycles
-        (NPLC) for the AC voltage measurements, which sets the integration period 
+        (NPLC) for the AC voltage measurements, which sets the integration period
         and measurement speed. Takes values from 0.01 to 10, where 0.1, 1, and 10 are
         Fast, Medium, and Slow respectively. """
     )
@@ -226,12 +236,12 @@ class Keithley2000(Instrument, KeithleyBuffer):
 
     resistance = Instrument.measurement(":READ?",
         """ Reads a resistance measurement in Ohms for both 2-wire and 4-wire
-        configurations, based on the active :attr:`~.mode`. """
+        configurations, based on the active :attr:`~.Keithley2000.mode`. """
     )
     resistance_range = Instrument.control(
         ":SENS:RES:RANG?", ":SENS:RES:RANG:AUTO 0;:SENS:RES:RANG %g",
-        """ A floating point property that controls the 2-wire resistance range 
-        in Ohms, which can take values from 0 to 120 MOhms. 
+        """ A floating point property that controls the 2-wire resistance range
+        in Ohms, which can take values from 0 to 120 MOhms.
         Auto-range is disabled when this property is set. """,
         validator=truncated_range,
         values=[0, 120e6]
@@ -246,7 +256,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
     resistance_nplc = Instrument.control(
         ":SENS:RES:NPLC?", ":SENS:RES:NPLC %g",
         """ A floating point property that controls the number of power line cycles
-        (NPLC) for the 2-wire resistance measurements, which sets the integration period 
+        (NPLC) for the 2-wire resistance measurements, which sets the integration period
         and measurement speed. Takes values from 0.01 to 10, where 0.1, 1, and 10 are
         Fast, Medium, and Slow respectively. """
     )
@@ -261,7 +271,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
     resistance_4W_range = Instrument.control(
         ":SENS:FRES:RANG?", ":SENS:FRES:RANG:AUTO 0;:SENS:FRES:RANG %g",
         """ A floating point property that controls the 4-wire resistance range
-        in Ohms, which can take values from 0 to 120 MOhms. 
+        in Ohms, which can take values from 0 to 120 MOhms.
         Auto-range is disabled when this property is set. """,
         validator=truncated_range,
         values=[0, 120e6]
@@ -276,7 +286,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
     resistance_4W_nplc = Instrument.control(
         ":SENS:FRES:NPLC?", ":SENS:FRES:NPLC %g",
         """ A floating point property that controls the number of power line cycles
-        (NPLC) for the 4-wire resistance measurements, which sets the integration period 
+        (NPLC) for the 4-wire resistance measurements, which sets the integration period
         and measurement speed. Takes values from 0.01 to 10, where 0.1, 1, and 10 are
         Fast, Medium, and Slow respectively. """
     )
@@ -295,7 +305,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
 
     frequency = Instrument.measurement(":READ?",
         """ Reads a frequency measurement in Hz, based on the
-        active :attr:`~.mode`. """
+        active :attr:`~.Keithley2000.mode`. """
     )
     frequency_reference = Instrument.control(
         ":SENS:FREQ:REF?", ":SENS:FREQ:REF %g",
@@ -335,7 +345,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
 
     period = Instrument.measurement(":READ?",
         """ Reads a period measurement in seconds, based on the
-        active :attr:`~.mode`. """
+        active :attr:`~.Keithley2000.mode`. """
     )
     period_reference = Instrument.control(
         ":SENS:PER:REF?", ":SENS:PER:REF %g",
@@ -375,7 +385,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
 
     temperature = Instrument.measurement(":READ?",
         """ Reads a temperature measurement in Celsius, based on the
-        active :attr:`~.mode`. """
+        active :attr:`~.Keithley2000.mode`. """
     )
     temperature_reference = Instrument.control(
         ":SENS:TEMP:REF?", ":SENS:TEMP:REF %g",
@@ -387,7 +397,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
     temperature_nplc = Instrument.control(
         ":SENS:TEMP:NPLC?", ":SENS:TEMP:NPLC %g",
         """ A floating point property that controls the number of power line cycles
-        (NPLC) for the temperature measurements, which sets the integration period 
+        (NPLC) for the temperature measurements, which sets the integration period
         and measurement speed. Takes values from 0.01 to 10, where 0.1, 1, and 10 are
         Fast, Medium, and Slow respectively. """
     )
@@ -512,7 +522,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
         """ Configures the instrument to perform continuity testing. """
         self.mode = 'continuity'
 
-    def _mode_command(mode=None):
+    def _mode_command(self, mode=None):
         if mode is None:
             mode = self.mode
         return self.MODES[mode]
@@ -521,7 +531,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
         """ Sets the active mode to use auto-range,
         or can set another mode by its name.
 
-        :param mode: A valid :attr:`~.mode` name, or None for the active mode
+        :param mode: A valid :attr:`~.Keithley2000.mode` name, or None for the active mode
         """
         self.write(":SENS:%s:RANG:AUTO 1" % self._mode_command(mode))
 
@@ -529,7 +539,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
         """ Enables the reference for the active mode,
         or can set another mode by its name.
 
-        :param mode: A valid :attr:`~.mode` name, or None for the active mode
+        :param mode: A valid :attr:`~.Keithley2000.mode` name, or None for the active mode
         """
         self.write(":SENS:%s:REF:STAT 1" % self._mode_command(mode))
 
@@ -537,7 +547,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
         """ Disables the reference for the active mode,
         or can set another mode by its name.
 
-        :param mode: A valid :attr:`~.mode` name, or None for the active mode
+        :param mode: A valid :attr:`~.Keithley2000.mode` name, or None for the active mode
         """
         self.write(":SENS:%s:REF:STAT 0" % self._mode_command(mode))
 
@@ -545,7 +555,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
         """ Sets the active value as the reference for the active mode,
         or can set another mode by its name.
 
-        :param mode: A valid :attr:`~.mode` name, or None for the active mode
+        :param mode: A valid :attr:`~.Keithley2000.mode` name, or None for the active mode
         """
         self.write(":SENS:%s:REF:ACQ" % self._mode_command(mode))
 
@@ -553,7 +563,7 @@ class Keithley2000(Instrument, KeithleyBuffer):
         """ Enables the averaging filter for the active mode,
         or can set another mode by its name.
 
-        :param mode: A valid :attr:`~.mode` name, or None for the active mode
+        :param mode: A valid :attr:`~.Keithley2000.mode` name, or None for the active mode
         :param type: The type of averaging filter, either 'repeat' or 'moving'.
         :param count: A number of averages, which can take take values from 1 to 100
         """
@@ -565,30 +575,30 @@ class Keithley2000(Instrument, KeithleyBuffer):
         """ Disables the averaging filter for the active mode,
         or can set another mode by its name.
 
-        :param mode: A valid :attr:`~.mode` name, or None for the active mode
+        :param mode: A valid :attr:`~.Keithley2000.mode` name, or None for the active mode
         """
         self.write(":SENS:%s:AVER:STAT 0" % self._mode_command(mode))
 
     def local(self):
-        """ Returns control to the instrument panel, and enables 
+        """ Returns control to the instrument panel, and enables
         the panel if disabled. """
         self.write(":SYST:LOC")
 
     def remote(self):
-        """ Places the instrument in the remote state, which is 
+        """ Places the instrument in the remote state, which is
         does not need to be explicity called in general. """
         self.write(":SYST:REM")
 
     def remote_lock(self):
         """ Disables and locks the front panel controls to prevent
         changes during remote operations. This is disabled by
-        calling :meth:`~.local`.  """
+        calling :meth:`~.Keithley2000.local`.  """
         self.write(":SYST:RWL")
 
     def reset(self):
         """ Resets the instrument state. """
         self.write(":STAT:QUEUE:CLEAR;*RST;:STAT:PRES;:*CLS;")
-        
+
     def beep(self, frequency, duration):
         """ Sounds a system beep.
 
